@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import cms.admin.pageadmin
 import cms.admin.useradmin
 import cms.admin.permissionadmin
@@ -6,7 +5,6 @@ import cms.admin.settingsadmin
 import cms.admin.static_placeholder  # nopyflakes
 # Piggyback off admin.autodiscover() to discover cms plugins
 from cms import plugin_pool
-from cms.apphook_pool import apphook_pool
-plugin_pool.plugin_pool.discover_plugins()
 
-apphook_pool.discover_apps()
+
+plugin_pool.plugin_pool.discover_plugins()
