@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from django import forms
 from django.apps import apps
 from django.contrib.auth import get_user_model, get_permission_codename
@@ -10,7 +9,7 @@ from django.forms.utils import ErrorList
 from django.forms.widgets import HiddenInput
 from django.template.defaultfilters import slugify
 from django.utils.encoding import force_text
-from django.utils.translation import ugettext, ugettext_lazy as _
+from django.utils.translation import gettext, gettext_lazy as _
 
 from cms import api
 from cms.apphook_pool import apphook_pool
@@ -163,7 +162,7 @@ class AddPageForm(BasePageForm):
         fields = ['source']
 
     def __init__(self, *args, **kwargs):
-        super(AddPageForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         source_field = self.fields.get('source')
 
@@ -267,7 +266,7 @@ class AddPageForm(BasePageForm):
             for lang in source.get_languages():
                 source._copy_contents(new_page, lang)
         else:
-            new_page = super(AddPageForm, self).save(commit=False)
+            new_page = super().save(commit=False)
             new_page.template = self.get_template()
             new_page.set_tree_node(self._site, target=parent, position='last-child')
             new_page.save()
@@ -328,7 +327,7 @@ class AddPageTypeForm(AddPageForm):
         if not root_page.has_translation(self._language):
             api.create_title(
                 language=self._language,
-                title=ugettext('Page Types'),
+                title=gettext('Page Types'),
                 page=root_page,
                 slug=PAGE_TYPES_ID,
                 path=PAGE_TYPES_ID,
@@ -336,7 +335,7 @@ class AddPageTypeForm(AddPageForm):
         return root_page.node
 
     def clean_parent_node(self):
-        parent_node = super(AddPageTypeForm, self).clean_parent_node()
+        parent_node = super().clean_parent_node()
 
         if parent_node and not parent_node.item.is_page_type:
             raise ValidationError("Parent has to be a page type.")
@@ -360,7 +359,7 @@ class AddPageTypeForm(AddPageForm):
         return new_page
 
     def save(self, *args, **kwargs):
-        new_page = super(AddPageTypeForm, self).save(*args, **kwargs)
+        new_page = super().save(*args, **kwargs)
 
         if not self.cleaned_data.get('source'):
             # User has created a page-type via "Add page"
@@ -392,7 +391,7 @@ class ChangePageForm(BasePageForm):
     )
 
     def __init__(self, *args, **kwargs):
-        super(ChangePageForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.title_obj = self.instance.get_title_obj(
             language=self._language,
             fallback=False,
@@ -404,7 +403,7 @@ class ChangePageForm(BasePageForm):
                 self.fields[field].initial = getattr(self.title_obj, field)
 
     def clean(self):
-        data = super(ChangePageForm, self).clean()
+        data = super().clean()
 
         if self._errors:
             # Form already has errors, best to let those be
@@ -450,7 +449,7 @@ class ChangePageForm(BasePageForm):
 
     def save(self, commit=True):
         data = self.cleaned_data
-        cms_page = super(ChangePageForm, self).save(commit=False)
+        cms_page = super().save(commit=False)
 
         translation_data = {field: data[field]
                             for field in self.translation_fields if field in data}
@@ -486,7 +485,7 @@ class PublicationDatesForm(forms.ModelForm):
         fields = ['publication_date', 'publication_end_date']
 
     def save(self, *args, **kwargs):
-        page = super(PublicationDatesForm, self).save(*args, **kwargs)
+        page = super().save(*args, **kwargs)
         page.clear_cache(menu=True)
         return page
 
@@ -544,7 +543,7 @@ class AdvancedSettingsForm(forms.ModelForm):
         ]
 
     def __init__(self, *args, **kwargs):
-        super(AdvancedSettingsForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.title_obj = self.instance.get_title_obj(
             language=self._language,
             fallback=False,
@@ -616,7 +615,7 @@ class AdvancedSettingsForm(forms.ModelForm):
         ).exclude(pk=self.instance.pk).exists()
 
     def clean(self):
-        cleaned_data = super(AdvancedSettingsForm, self).clean()
+        cleaned_data = super().clean()
 
         if self._errors:
             # Fail fast if there's errors in the form
@@ -762,7 +761,7 @@ class AdvancedSettingsForm(forms.ModelForm):
 
     def save(self, *args, **kwargs):
         data = self.cleaned_data
-        page = super(AdvancedSettingsForm, self).save(*args, **kwargs)
+        page = super().save(*args, **kwargs)
         page.update_translations(
             self._language,
             path=data['path'],
@@ -785,7 +784,7 @@ class PagePermissionForm(forms.ModelForm):
         fields = ['login_required', 'limit_visibility_in_menu']
 
     def save(self, *args, **kwargs):
-        page = super(PagePermissionForm, self).save(*args, **kwargs)
+        page = super().save(*args, **kwargs)
         page.clear_cache(menu=True)
         clear_permission_cache()
         return page
@@ -799,7 +798,7 @@ class PageTreeForm(forms.Form):
     def __init__(self, *args, **kwargs):
         self.page = kwargs.pop('page')
         self._site = kwargs.pop('site', Site.objects.get_current())
-        super(PageTreeForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.fields['target'].queryset = Page.objects.drafts().filter(
             node__site=self._site,
             is_page_type=self.page.is_page_type,
@@ -849,14 +848,14 @@ class PageTreeForm(forms.Form):
 class MovePageForm(PageTreeForm):
 
     def clean(self):
-        cleaned_data = super(MovePageForm, self).clean()
+        cleaned_data = super().clean()
 
         if self.page.is_home and cleaned_data.get('target'):
             self.add_error('target', force_text(_('You can\'t move the home page inside another page')))
         return cleaned_data
 
     def get_tree_options(self):
-        options = super(MovePageForm, self).get_tree_options()
+        options = super().get_tree_options()
         target_node, target_node_position = options
 
         if target_node_position != 'left':
@@ -903,7 +902,7 @@ class CopyPageForm(PageTreeForm):
 
     def _get_tree_options_for_root(self, position):
         try:
-            return super(CopyPageForm, self)._get_tree_options_for_root(position)
+            return super()._get_tree_options_for_root(position)
         except IndexError:
             # The user is copying a page to a site with no pages
             # Add the node as the last root node.
@@ -925,7 +924,7 @@ class ChangeListForm(forms.Form):
     soft_root = forms.ChoiceField(required=False, choices=BOOLEAN_CHOICES)
 
     def __init__(self, *args, **kwargs):
-        super(ChangeListForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.fields['changed_by'].choices = get_page_changed_by_filter_choices()
         self.fields['template'].choices = get_page_template_filter_choices()
 
@@ -953,7 +952,7 @@ class ChangeListForm(forms.Form):
 class BasePermissionAdminForm(forms.ModelForm):
 
     def __init__(self, *args, **kwargs):
-        super(BasePermissionAdminForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         permission_fields = self._meta.model.get_all_permissions()
 
         for field in permission_fields:
@@ -976,7 +975,7 @@ class PagePermissionInlineAdminForm(BasePermissionAdminForm):
     )
 
     def __init__(self, *args, **kwargs):
-        super(PagePermissionInlineAdminForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         user = get_current_user() # current user from threadlocals
         site = Site.objects.get_current()
         sub_users = get_subordinate_users(user, site)
@@ -1111,10 +1110,10 @@ class GenericCmsPermissionForm(forms.ModelForm):
             initial = initial or {}
             initial.update(self.populate_initials(instance))
             kwargs['initial'] = initial
-        super(GenericCmsPermissionForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def clean(self):
-        data = super(GenericCmsPermissionForm, self).clean()
+        data = super().clean()
 
         # Validate Page options
         if not data.get('can_change_page'):
@@ -1166,7 +1165,7 @@ class GenericCmsPermissionForm(forms.ModelForm):
         return initials
 
     def save(self, commit=True):
-        instance = super(GenericCmsPermissionForm, self).save(commit=False)
+        instance = super().save(commit=False)
         instance.save()
         save_permissions(self.cleaned_data, instance)
         return instance
@@ -1182,7 +1181,7 @@ class PageUserAddForm(forms.ModelForm):
         model = PageUser
 
     def __init__(self, *args, **kwargs):
-        super(PageUserAddForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.fields['user'].queryset = self.get_subordinates()
 
     def get_subordinates(self):
@@ -1191,7 +1190,7 @@ class PageUserAddForm(forms.ModelForm):
 
     def save(self, commit=True):
         user = self.cleaned_data['user']
-        instance = super(PageUserAddForm, self).save(commit=False)
+        instance = super().save(commit=False)
         instance.created_by = self._current_user
 
         for field in user._meta.fields:
@@ -1214,7 +1213,7 @@ class PageUserChangeForm(UserChangeForm):
         model = PageUser
 
     def __init__(self, *args, **kwargs):
-        super(PageUserChangeForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         if not self._current_user.is_superuser:
             # Limit permissions to include only
@@ -1244,7 +1243,7 @@ class PageUserGroupForm(GenericCmsPermissionForm):
     def save(self, commit=True):
         if not self.instance.pk:
             self.instance.created_by = self._current_user
-        return super(PageUserGroupForm, self).save(commit=commit)
+        return super().save(commit=commit)
 
 
 class PluginAddValidationForm(forms.Form):
@@ -1265,7 +1264,7 @@ class PluginAddValidationForm(forms.Form):
         try:
             plugin_pool.get_plugin(plugin_type)
         except KeyError:
-            message = ugettext("Invalid plugin type '%s'") % plugin_type
+            message = gettext("Invalid plugin type '%s'") % plugin_type
             raise ValidationError(message)
         return plugin_type
 
@@ -1282,18 +1281,18 @@ class PluginAddValidationForm(forms.Form):
         parent_plugin = data.get('plugin_parent')
 
         if language not in get_language_list():
-            message = ugettext("Language must be set to a supported language!")
+            message = gettext("Language must be set to a supported language!")
             self.add_error('plugin_language', message)
             return self.cleaned_data
 
         if parent_plugin:
             if parent_plugin.language != language:
-                message = ugettext("Parent plugin language must be same as language!")
+                message = gettext("Parent plugin language must be same as language!")
                 self.add_error('plugin_language', message)
                 return self.cleaned_data
 
             if parent_plugin.placeholder_id != placeholder.pk:
-                message = ugettext("Parent plugin placeholder must be same as placeholder!")
+                message = gettext("Parent plugin placeholder must be same as placeholder!")
                 self.add_error('placeholder_id', message)
                 return self.cleaned_data
 
