@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from collections import namedtuple
 import copy
 import json
@@ -9,7 +8,7 @@ import uuid
 import django
 from django.contrib.admin.helpers import AdminForm
 from django.conf import settings
-from django.conf.urls import url
+from django.urls import re_path
 from django.contrib import admin, messages
 from django.contrib.admin.models import LogEntry, CHANGE
 from django.contrib.admin.options import IS_POPUP_VAR
@@ -32,7 +31,7 @@ from django.template.defaultfilters import escape
 from django.template.loader import get_template
 from django.template.response import SimpleTemplateResponse, TemplateResponse
 from django.utils.encoding import force_text
-from django.utils.translation import ugettext, ugettext_lazy as _, get_language
+from django.utils.translation import gettext, gettext_lazy as _, get_language
 from django.utils.decorators import method_decorator
 from django.views.decorators.http import require_POST
 from django.http import QueryDict
@@ -73,7 +72,6 @@ from cms.utils.i18n import (
     get_site_language_from_request,
 )
 from cms.utils.admin import jsonify_request
-from cms.utils.compat import DJANGO_2_0
 from cms.utils.conf import get_cms_setting
 from cms.utils.urlutils import admin_reverse
 
@@ -131,7 +129,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
 
     def get_queryset(self, request):
         site = self.get_site(request)
-        queryset = super(BasePageAdmin, self).get_queryset(request)
+        queryset = super().get_queryset(request)
         queryset = queryset.filter(node__site=site, publisher_is_draft=True)
         return queryset.select_related('node')
 
@@ -175,7 +173,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
         """Get the admin urls
         """
         info = "%s_%s" % (self.model._meta.app_label, self.model._meta.model_name)
-        pat = lambda regex, fn: url(regex, self.admin_site.admin_view(fn), name='%s_%s' % (info, fn.__name__))
+        def pat(regex, fn): return re_path(regex, self.admin_site.admin_view(fn), name='%s_%s' % (info, fn.__name__))
 
         url_patterns = [
             pat(r'^([0-9]+)/advanced-settings/$', self.advanced),
@@ -198,7 +196,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
             pat(r'^([0-9]+)/([a-z\-]+)/revert-to-live/$', self.revert_to_live),
             pat(r'^get-tree/$', self.get_tree),
         ]
-        return url_patterns + super(BasePageAdmin, self).get_urls()
+        return url_patterns + super().get_urls()
 
     def _send_pre_page_operation(self, request, operation, **kwargs):
         token = str(uuid.uuid4())
@@ -239,7 +237,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
 
     def get_inline_instances(self, request, obj=None):
         if obj and 'permission' in request.path_info:
-            return super(BasePageAdmin, self).get_inline_instances(request, obj)
+            return super().get_inline_instances(request, obj)
         return []
 
     def get_form_class(self, request, obj=None, **kwargs):
@@ -260,7 +258,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
         Get PageForm for the Page model and modify its fields depending on
         the request.
         """
-        form = super(BasePageAdmin, self).get_form(
+        form = super().get_form(
             request,
             obj,
             form=self.get_form_class(request, obj),
@@ -382,7 +380,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
             'language': language,
         })
         extra_context.update(self.get_unihandecode_context(language))
-        return super(BasePageAdmin, self).add_view(request, form_url, extra_context=extra_context)
+        return super().add_view(request, form_url, extra_context=extra_context)
 
     def change_view(self, request, object_id, form_url='', extra_context=None):
         """
@@ -416,7 +414,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
         tab_language = get_site_language_from_request(request, site_id=site.pk)
         extra_context.update(self.get_unihandecode_context(tab_language))
 
-        response = super(BasePageAdmin, self).change_view(
+        response = super().change_view(
             request, object_id, form_url=form_url, extra_context=extra_context)
         if tab_language and response.status_code == 302 and response._headers['location'][1] == request.path_info:
             location = response._headers['location']
@@ -438,20 +436,13 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
         if obj is None:
             raise self._get_404_exception(object_id)
 
-        using = router.db_for_write(self.model)
+        router.db_for_write(self.model)
 
         # Populate deleted_objects, a data structure of all related objects that
         # will also be deleted.
         objs = [obj] + list(obj.get_descendant_pages())
 
-        if DJANGO_2_0:
-            get_deleted_objects_additional_kwargs = {
-                'opts': opts,
-                'using': using,
-                'user': request.user,
-            }
-        else:
-            get_deleted_objects_additional_kwargs = {'request': request}
+        get_deleted_objects_additional_kwargs = {'request': request}
         (deleted_objects, model_count, perms_needed, protected) = get_deleted_objects(
             objs, admin_site=self.admin_site,
             **get_deleted_objects_additional_kwargs
@@ -512,7 +503,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
             page._clear_placeholders()
             page.get_placeholders().delete()
 
-        super(BasePageAdmin, self).delete_model(request, obj)
+        super().delete_model(request, obj)
 
         self._send_post_page_operation(
             request,
@@ -583,7 +574,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
 
     def render_change_form(self, request, context, add=False, change=False, form_url='', obj=None):
         context['filled_languages'] = self.get_filled_languages(request, obj)
-        return super(BasePageAdmin, self).render_change_form(request, context, add, change, form_url, obj)
+        return super().render_change_form(request, context, add, change, form_url, obj)
 
     def _get_site_languages(self, request, obj=None):
         if obj:
@@ -613,7 +604,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
         This override is in place to preserve the "language" get parameter in
         the "Save" page redirect
         """
-        preserved_filters_encoded = super(BasePageAdmin, self).get_preserved_filters(request)
+        preserved_filters_encoded = super().get_preserved_filters(request)
         preserved_filters = QueryDict(preserved_filters_encoded).copy()
         lang = request.GET.get('language')
 
@@ -744,7 +735,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
     def lookup_allowed(self, key, *args, **kwargs):
         if key == 'site__exact':
             return True
-        return super(BasePageAdmin, self).lookup_allowed(key, *args, **kwargs)
+        return super().lookup_allowed(key, *args, **kwargs)
 
     def get_sites_for_user(self, user):
         sites = Site.objects.order_by('name')
@@ -1282,25 +1273,19 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
 
         titleopts = Title._meta
         app_label = titleopts.app_label
-        pluginopts = CMSPlugin._meta
+        CMSPlugin._meta
 
         saved_plugins = CMSPlugin.objects.filter(placeholder__page__id=object_id, language=language)
-        using = router.db_for_read(self.model)
+        router.db_for_read(self.model)
 
         kwargs = {'admin_site': self.admin_site}
-        if DJANGO_2_0:
-            kwargs.update({'using': using, 'opts': titleopts, 'user': request.user})
-        else:
-            kwargs.update({'request': request})
+        kwargs.update({'request': request})
         deleted_objects, __, perms_needed = get_deleted_objects(
             [translation],
             **kwargs
         )[:3]
 
-        if DJANGO_2_0:
-            kwargs.update({'using': using, 'opts': pluginopts, 'user': request.user})
-        else:
-            kwargs.update({'request': request})
+        kwargs.update({'request': request})
         to_delete_plugins, __, perms_needed_plugins = get_deleted_objects(
             saved_plugins,
             **kwargs
@@ -1389,7 +1374,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
             can_see_page = page.is_published(language)
 
         if not can_see_page:
-            message = ugettext('You don\'t have permissions to see page "%(title)s"')
+            message = gettext('You don\'t have permissions to see page "%(title)s"')
             message = message % {'title': force_text(page)}
             self.message_user(request, message, level=messages.ERROR)
             return HttpResponseRedirect(self.get_admin_url('changelist'))
@@ -1438,7 +1423,7 @@ class BasePageAdmin(PlaceholderAdminMixin, admin.ModelAdmin):
 
         if node_id:
             page = get_object_or_404(pages, node_id=int(node_id))
-            pages = page.get_descendant_pages().filter(Q(node__in=open_nodes)|Q(node__parent__in=open_nodes))
+            pages = page.get_descendant_pages().filter(Q(node__in=open_nodes) |Q(node__parent__in=open_nodes))
         else:
             page = None
             pages = pages.filter(
@@ -1683,27 +1668,27 @@ class PageAdmin(BasePageAdmin):
             extra_context.update({
                 'title':  _("New page"),
             })
-        return super(PageAdmin, self).add_view(request, form_url, extra_context=extra_context)
+        return super().add_view(request, form_url, extra_context=extra_context)
 
     def get_queryset(self, request):
-        queryset  = super(PageAdmin, self).get_queryset(request)
+        queryset  = super().get_queryset(request)
         return queryset.exclude(is_page_type=True)
 
     def get_urls(self):
         """Get the admin urls
         """
         info = "%s_%s" % (self.model._meta.app_label, self.model._meta.model_name)
-        pat = lambda regex, fn: url(regex, self.admin_site.admin_view(fn), name='%s_%s' % (info, fn.__name__))
+        def pat(regex, fn): return re_path(regex, self.admin_site.admin_view(fn), name='%s_%s' % (info, fn.__name__))
 
         url_patterns = [
             pat(r'^([0-9]+)/set-home/$', self.set_home),
             pat(r'^published-pages/$', self.get_published_pagelist),
-            url(r'^resolve/$', self.resolve, name="cms_page_resolve"),
+            re_path(r'^resolve/$', self.resolve, name="cms_page_resolve"),
         ]
 
         if plugin_pool.registered_plugins:
             url_patterns += plugin_pool.get_patterns()
-        return url_patterns + super(PageAdmin, self).get_urls()
+        return url_patterns + super().get_urls()
 
     @require_POST
     @transaction.atomic
@@ -1743,7 +1728,7 @@ class PageAdmin(BasePageAdmin):
         """
         request = args[0]
 
-        if request.is_ajax():
+        if request.headers.get('x-requested-with') == 'XMLHttpRequest':
             query_term = request.GET.get('q','').strip('/')
 
             language_code = request.GET.get('language_code', settings.LANGUAGE_CODE)
@@ -1773,7 +1758,7 @@ class PageTypeAdmin(BasePageAdmin):
     change_form_template = 'admin/cms/page/change_form.html'
 
     def get_queryset(self, request):
-        queryset  = super(PageTypeAdmin, self).get_queryset(request)
+        queryset  = super().get_queryset(request)
         return queryset.exclude(is_page_type=False)
 
 
