@@ -1,8 +1,9 @@
-# -*- coding: utf-8 -*-
 import uuid
 import warnings
 
-from django.conf.urls import url
+from urllib.parse import parse_qsl, urlparse
+
+from django.urls import re_path
 from django.contrib.admin.helpers import AdminForm
 from django.contrib.admin.utils import get_deleted_objects
 from django.core.exceptions import PermissionDenied
@@ -18,15 +19,12 @@ from django.shortcuts import get_list_or_404, get_object_or_404, render
 from django.template.response import TemplateResponse
 from django.utils.decorators import method_decorator
 from django.utils.encoding import force_text
+from django.utils.html import conditional_escape
 from django.utils import translation
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.decorators.clickjacking import xframe_options_sameorigin
 from django.views.decorators.http import require_POST
 
-from six.moves.urllib.parse import parse_qsl, urlparse
-
-from six import get_unbound_function, get_method_function
-
 from cms import operations
 from cms.admin.forms import PluginAddValidationForm
 from cms.constants import SLUG_REGEXP
@@ -38,7 +36,6 @@ from cms.plugin_pool import plugin_pool
 from cms.signals import pre_placeholder_operation, post_placeholder_operation
 from cms.toolbar.utils import get_plugin_tree_as_json
 from cms.utils import copy_plugins, get_current_site
-from cms.utils.compat import DJANGO_2_0
 from cms.utils.conf import get_cms_setting
 from cms.utils.i18n import get_language_code, get_language_list
 from cms.utils.plugins import has_reached_plugin_limit, reorder_plugins
@@ -68,12 +65,12 @@ def _instance_overrides_method(base, instance, method_name):
     Returns True if instance overrides a method (method_name)
     inherited from base.
     """
-    bound_method = getattr(instance, method_name)
+    bound_method = getattr(instance.__class__, method_name)
     unbound_method = getattr(base, method_name)
-    return get_unbound_function(unbound_method) != get_method_function(bound_method)
+    return unbound_method != bound_method
 
 
-class FrontendEditableAdminMixin(object):
+class FrontendEditableAdminMixin:
     frontend_editable_fields = []
 
     def get_urls(self):
@@ -81,11 +78,11 @@ class FrontendEditableAdminMixin(object):
         Register the url for the single field edit view
         """
         info = "%s_%s" % (self.model._meta.app_label, self.model._meta.model_name)
-        pat = lambda regex, fn: url(regex, self.admin_site.admin_view(fn), name='%s_%s' % (info, fn.__name__))
+        def pat(regex, fn): return re_path(regex, self.admin_site.admin_view(fn), name='%s_%s' % (info, fn.__name__))
         url_patterns = [
             pat(r'edit-field/(%s)/([a-z\-]+)/$' % SLUG_REGEXP, self.edit_field),
         ]
-        return url_patterns + super(FrontendEditableAdminMixin, self).get_urls()
+        return url_patterns + super().get_urls()
 
     def _get_object_for_single_field(self, object_id, language):
         # Quick and dirty way to retrieve objects for django-hvad
@@ -154,7 +151,7 @@ class FrontendEditableAdminMixin(object):
         return render(request, 'admin/cms/page/plugin/change_form.html', context)
 
 
-class PlaceholderAdminMixin(object):
+class PlaceholderAdminMixin:
 
     def _get_attached_admin(self, placeholder):
         return placeholder._get_attached_admin(admin_site=self.admin_site)
@@ -227,7 +224,7 @@ class PlaceholderAdminMixin(object):
         Register the plugin specific urls (add/edit/copy/remove/move)
         """
         info = "%s_%s" % (self.model._meta.app_label, self.model._meta.model_name)
-        pat = lambda regex, fn: url(regex, self.admin_site.admin_view(fn), name='%s_%s' % (info, fn.__name__))
+        def pat(regex, fn): return re_path(regex, self.admin_site.admin_view(fn), name='%s_%s' % (info, fn.__name__))
         url_patterns = [
             pat(r'copy-plugins/$', self.copy_plugins),
             pat(r'add-plugin/$', self.add_plugin),
@@ -236,7 +233,7 @@ class PlaceholderAdminMixin(object):
             pat(r'clear-placeholder/(%s)/$' % SLUG_REGEXP, self.clear_placeholder),
             pat(r'move-plugin/$', self.move_plugin),
         ]
-        return url_patterns + super(PlaceholderAdminMixin, self).get_urls()
+        return url_patterns + super().get_urls()
 
     def has_add_plugin_permission(self, request, placeholder, plugin_type):
         return placeholder.has_add_plugin_permission(request.user, plugin_type)
@@ -304,7 +301,7 @@ class PlaceholderAdminMixin(object):
             # errors is s dict mapping fields to a list of errors
             # for that field.
             error = list(form.errors.values())[0][0]
-            return HttpResponseBadRequest(force_text(error))
+            return HttpResponseBadRequest(conditional_escape(force_text(error)))
 
         plugin_data = form.cleaned_data
         placeholder = plugin_data['placeholder_id']
@@ -1031,15 +1028,8 @@ class PlaceholderAdminMixin(object):
                 _("You do not have permission to delete this plugin")))
 
         opts = plugin._meta
-        using = router.db_for_write(opts.model)
-        if DJANGO_2_0:
-            get_deleted_objects_additional_kwargs = {
-                'opts': opts,
-                'using': using,
-                'user': request.user,
-            }
-        else:
-            get_deleted_objects_additional_kwargs = {'request': request}
+        router.db_for_write(opts.model)
+        get_deleted_objects_additional_kwargs = {'request': request}
         deleted_objects, __, perms_needed, protected = get_deleted_objects(
             [plugin], admin_site=self.admin_site,
             **get_deleted_objects_additional_kwargs
@@ -1128,17 +1118,10 @@ class PlaceholderAdminMixin(object):
             return HttpResponseForbidden(force_text(_("You do not have permission to clear this placeholder")))
 
         opts = Placeholder._meta
-        using = router.db_for_write(Placeholder)
+        router.db_for_write(Placeholder)
         plugins = placeholder.get_plugins_list(language)
 
-        if DJANGO_2_0:
-            get_deleted_objects_additional_kwargs = {
-                'opts': opts,
-                'using': using,
-                'user': request.user,
-            }
-        else:
-            get_deleted_objects_additional_kwargs = {'request': request}
+        get_deleted_objects_additional_kwargs = {'request': request}
         deleted_objects, __, perms_needed, protected = get_deleted_objects(
             plugins, admin_site=self.admin_site,
             **get_deleted_objects_additional_kwargs
