@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
 from operator import attrgetter
 
 from django.core.exceptions import ImproperlyConfigured
-from django.conf.urls import url, include
+from django.urls import re_path, include
 from django.template.defaultfilters import slugify
 from django.utils.encoding import force_text
 from django.utils.functional import cached_property
@@ -10,15 +9,13 @@ from django.utils.module_loading import autodiscover_modules
 from django.utils.translation import get_language, deactivate_all, activate
 from django.template import TemplateDoesNotExist, TemplateSyntaxError
 
-from six import string_types, text_type
-
 from cms.exceptions import PluginAlreadyRegistered, PluginNotRegistered
 from cms.plugin_base import CMSPluginBase
 from cms.utils.conf import get_cms_setting
 from cms.utils.helpers import normalize_name
 
 
-class PluginPool(object):
+class PluginPool:
 
     def __init__(self):
         self.plugins = {}
@@ -78,7 +75,7 @@ class PluginPool(object):
                     from django.template import loader
 
                     template = plugin.render_template
-                    if isinstance(template, string_types) and template:
+                    if isinstance(template, str) and template:
                         try:
                             loader.get_template(template)
                         except TemplateDoesNotExist as e:
@@ -86,7 +83,7 @@ class PluginPool(object):
                             # TemplateDoesNotExist if the plugin's render_template
                             # does in fact exist, but it includes a template that
                             # doesn't.
-                            if text_type(e) == template:
+                            if str(e) == template:
                                 raise ImproperlyConfigured(
                                     "CMS Plugins must define a render template (%s) that exists: %s"
                                     % (plugin, template)
@@ -202,7 +199,7 @@ class PluginPool(object):
                 p = plugin()
                 slug = slugify(force_text(normalize_name(p.__class__.__name__)))
                 url_patterns += [
-                    url(r'^plugin/%s/' % (slug,), include(p.plugin_urls)),
+                    re_path(r'^plugin/%s/' % (slug,), include(p.plugin_urls)),
                 ]
         finally:
             # Reactivate translation
