@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from collections import namedtuple, OrderedDict
 from copy import copy
 from datetime import datetime
@@ -17,11 +16,9 @@ from django.utils.http import urlencode
 from django.utils.translation import (
     get_language,
     override as force_language,
-    ugettext_lazy as _,
+    gettext_lazy as _,
 )
 
-from six import string_types, integer_types
-
 from classytags.arguments import (Argument, MultiValueArgument,
                                   MultiKeywordArgument)
 from classytags.core import Options, Tag
@@ -36,7 +33,6 @@ from cms.models import Page, Placeholder as PlaceholderModel, CMSPlugin, StaticP
 from cms.plugin_pool import plugin_pool
 from cms.toolbar.utils import get_toolbar_from_request
 from cms.utils import get_current_site, get_language_from_request, get_site_id
-from cms.utils.compat.dj import get_middleware
 from cms.utils.moderator import use_draft
 from cms.utils.page import get_page_queryset
 from cms.utils.placeholder import validate_placeholder_name
@@ -69,9 +65,9 @@ def _get_page_by_untyped_arg(page_lookup, request, site_id):
         if request.current_page and request.current_page.pk == page_lookup.pk:
             return request.current_page
         return page_lookup
-    if isinstance(page_lookup, string_types):
+    if isinstance(page_lookup, str):
         page_lookup = {'reverse_id': page_lookup}
-    elif isinstance(page_lookup, integer_types):
+    elif isinstance(page_lookup, int):
         page_lookup = {'pk': page_lookup}
     elif not isinstance(page_lookup, dict):
         raise TypeError('The page_lookup argument can be either a Dictionary, Integer, Page, or String.')
@@ -100,7 +96,7 @@ def _get_page_by_untyped_arg(page_lookup, request, site_id):
         if settings.DEBUG:
             raise Page.DoesNotExist(body)
         else:
-            mw = get_middleware()
+            mw = settings.MIDDLEWARE
             if getattr(settings, 'SEND_BROKEN_LINK_EMAILS', False):
                 mail_managers(subject, body, fail_silently=True)
             elif 'django.middleware.common.BrokenLinkEmailsMiddleware' in mw:
@@ -223,7 +219,7 @@ class PageUrl(AsTag):
         # settings.DEBUG=False.
         #
         try:
-            return super(PageUrl, self).get_value_for_context(context, **kwargs)
+            return super().get_value_for_context(context, **kwargs)
         except Page.DoesNotExist:
             return ''
 
@@ -254,7 +250,7 @@ class PlaceholderParser(Parser):
     def parse_blocks(self):
         for bit in getattr(self.kwargs['extra_bits'], 'value', self.kwargs['extra_bits']):
             if getattr(bit, 'value', bit.var.value) == 'or':
-                return super(PlaceholderParser, self).parse_blocks()
+                return super().parse_blocks()
         return
 
 
@@ -470,7 +466,7 @@ class CMSEditableObject(InclusionTag):
 
     def __init__(self, parser, tokens):
         self.parser = parser
-        super(CMSEditableObject, self).__init__(parser, tokens)
+        super().__init__(parser, tokens)
 
     def _is_editable(self, request):
         return (request and hasattr(request, 'toolbar') and request.toolbar.edit_mode_active)
@@ -521,7 +517,7 @@ class CMSEditableObject(InclusionTag):
                 if not context.get('attribute_name', None):
                     # Make sure CMS.Plugin object will not clash in the frontend.
                     extra_context['attribute_name'] = '-'.join(edit_fields) \
-                                                        if not isinstance('edit_fields', string_types) else edit_fields
+                                                        if not isinstance('edit_fields', str) else edit_fields
             else:
                 instance.get_plugin_name = u"%s %s" % (smart_text(_('Add')), smart_text(opts.verbose_name))
                 extra_context['attribute_name'] = 'add'
@@ -926,7 +922,7 @@ class RenderPlaceholder(AsTag):
         if not placeholder:
             return ''
 
-        if isinstance(placeholder, string_types):
+        if isinstance(placeholder, str):
             placeholder = PlaceholderModel.objects.get(slot=placeholder)
 
         content = renderer.render_placeholder(
@@ -956,7 +952,7 @@ class RenderUncachedPlaceholder(RenderPlaceholder):
 
     def _get_value(self, context, editable=True, **kwargs):
         kwargs['nocache'] = True
-        return super(RenderUncachedPlaceholder, self)._get_value(context, editable, **kwargs)
+        return super()._get_value(context, editable, **kwargs)
 
 
 class EmptyListValue(list, StringValue):
@@ -981,7 +977,7 @@ class MultiValueArgumentBeforeKeywordArgument(MultiValueArgument):
             if self.name not in kwargs:
                 kwargs[self.name] = self.sequence_class()
             return False
-        return super(MultiValueArgumentBeforeKeywordArgument, self).parse(
+        return super().parse(
             parser,
             token,
             tagname,
