@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from cms.models import CMSPlugin
 
 
@@ -6,10 +5,10 @@ class TestPlugin1(CMSPlugin):
     pass
 
 
-class LeftMixin(object): pass
+class LeftMixin: pass
 
-class RightMixin(object): pass
+class RightMixin: pass
 
 
 class TestPlugin2(LeftMixin, CMSPlugin, RightMixin):
-    pass
\ No newline at end of file
+    pass
