@@ -1,9 +1,9 @@
 
 from django.conf import settings
-from django.conf.urls import include, url
 from django.contrib import admin
 from django.contrib.staticfiles.urls import staticfiles_urlpatterns
 from django.conf.urls.i18n import i18n_patterns
+from django.urls import include, re_path
 from django.views.i18n import JavaScriptCatalog
 from django.views.static import serve
 
@@ -13,18 +13,18 @@ from cms.utils.conf import get_cms_setting
 admin.autodiscover()
 
 urlpatterns = [
-    url(r'^media/(?P<path>.*)$', serve,
-        {'document_root': settings.MEDIA_ROOT, 'show_indexes': True}),
-    url(r'^media/cms/(?P<path>.*)$', serve,
-        {'document_root': get_cms_setting('MEDIA_ROOT'), 'show_indexes': True}),
-    url(r'^jsi18n/(?P<packages>\S+?)/$', JavaScriptCatalog.as_view()),
+    re_path(r'^media/(?P<path>.*)$', serve,
+            {'document_root': settings.MEDIA_ROOT, 'show_indexes': True}),
+    re_path(r'^media/cms/(?P<path>.*)$', serve,
+            {'document_root': get_cms_setting('MEDIA_ROOT'), 'show_indexes': True}),
+    re_path(r'^jsi18n/(?P<packages>\S+?)/$', JavaScriptCatalog.as_view()),
 ]
 
 urlpatterns += staticfiles_urlpatterns()
 
 
 urlpatterns += i18n_patterns(
-    url(r'^admin/', admin.site.urls),
-    url(r'^example/$', example_view),
-    url(r'^', include('cms.urls')),
+    re_path(r'^admin/', admin.site.urls),
+    re_path(r'^example/$', example_view),
+    re_path(r'^', include('cms.urls')),
 )
