@@ -1,5 +1,5 @@
 from django.test.simple import DjangoTestSuiteRunner
-from cms.utils.compat.dj import force_unicode
+from django.utils.encoding import force_text
 import operator
 import time
 from django.utils.unittest import TestSuite
@@ -13,23 +13,23 @@ def time_it(func):
         func(*args, **kwargs)
         end = time.time()
 
-        TIMINGS[force_unicode(func)] = end - start
+        TIMINGS[force_text(func)] = end - start
     return _inner
 
 
 class TimingSuite(TestSuite):
     def addTest(self, test):
         test = time_it(test)
-        super(TimingSuite, self).addTest(test)
+        super().addTest(test)
 
 
 class TimedTestRunner(DjangoTestSuiteRunner):
     def build_suite(self, test_labels, extra_tests=None, **kwargs):
-        suite = super(TimedTestRunner, self).build_suite(test_labels, extra_tests, **kwargs)
+        suite = super().build_suite(test_labels, extra_tests, **kwargs)
         return TimingSuite(suite)
 
     def teardown_test_environment(self, **kwargs):
-        super(TimedTestRunner, self).teardown_test_environment(**kwargs)
+        super().teardown_test_environment(**kwargs)
         by_time = sorted(
                 TIMINGS.items(),
                 key=operator.itemgetter(1),
