@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import hashlib
 
 from django.core.exceptions import ImproperlyConfigured
@@ -6,14 +5,12 @@ from django.forms.models import ModelForm
 from django.utils.encoding import force_text
 from django.utils.functional import cached_property
 
-from django.utils.translation import override as force_language, ugettext as _
+from django.utils.translation import override as force_language, gettext as _
 
 from cms.utils.conf import get_cms_setting
 
-from six import python_2_unicode_compatible
 
-
-class WizardBase(object):
+class WizardBase:
     template_name = None
 
     def __init__(self, title, weight, form, model=None, template_name=None,
@@ -43,7 +40,6 @@ class WizardBase(object):
             self.template_name = template_name
 
 
-@python_2_unicode_compatible
 class Wizard(WizardBase):
     template_name = 'cms/wizards/create.html'
     _hash_cache = None
